==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Menu/MainMenu/BoardListViewMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Net;
using System.IO;
using System.Threading;

using nispi.controlclass;
using nispi.Menu;

namespace nispi
{
    class BoardListViewMainMenu
    {
        public ToolStripMenuItemParts menuItemDownloadParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemAlreadyReadParts;
        public ToolStripMenuItemParts menuItemNotReadParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        //public ToolStripMenuItemParts menuItemSelectAllParts;
        public ToolStripMenuItemParts menuItemDeleteLogParts;
        public ToolStripMenuItemParts menuItemSaveHtmlParts;
        public ToolStripMenuItemParts menuItemSaveDatParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemReloadParts;

        public ListViewPartMenuEvent listViewPartMenuEvent;

        public BoardListViewMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemDownloadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAlreadyReadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemNotReadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            //menuItemSelectAllParts = ToolStripMenuItemPartsManager.Pop();
            menuItemDeleteLogParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSaveHtmlParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSaveDatParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();

            //Cj[̐ݒ
            menuItemDownloadParts.Text = "J";

            menuItemAddFavoriteParts.Text = "Cɓɒǉ";

            menuItemAlreadyReadParts.Text = "ǂɂ";

            menuItemNotReadParts.Text = "ǂɂ";

            menuItemCopyURLParts.Text = "URLRs[";

            menuItemCopyTitleParts.Text = "ORs[";

            //menuItemSelectAllParts.Text = "ׂđI";

            menuItemDeleteLogParts.Text = "O폜";

            menuItemSaveHtmlParts.Text = "HTML`ŕۑ";

            menuItemSaveDatParts.Text = "DAT`ŕۑ";

            menuItemOpenBrowserParts.Text = "uEUŊJ";



            menuItem.DropDownItemsAdd(menuItemDownloadParts);
            menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemAlreadyReadParts);
            menuItem.DropDownItemsAdd(menuItemNotReadParts);
            //menuItem.DropDownItemsAdd(menuItemSelectAllParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemDeleteLogParts);
            menuItem.DropDownItemsAdd(menuItemSaveHtmlParts);
            menuItem.DropDownItemsAdd(menuItemSaveDatParts);

            listViewPartMenuEvent = new ListViewPartMenuEvent(this);
        }

        //Cj[̐ݒ
        public void SetMenu()
        {
            int index = Const.form.boardListTabControlParts.SelectedIndex;

            //Cɓ̃^ȕꍇ
            if (index == 0)
            {
                if ((MainFormConst.boardListTabMain.view_list[0].boardListControls.listViewParts.FocusedItem != null) &&
                    (MainFormConst.boardListTabMain.view_list[0].boardListControls.listViewParts.FocusedItem_Name.Length > 0))
                {
                    AllTrue();
                    menuItemAddFavoriteParts.Enabled = false;
                    
                }
                //Xg̃ACeIĂȂ
                else
                {
                    AllFalse();
                }
            }
            else if (index >= 1)
            {
                //Xg̃ACeIĂ
                if ((MainFormConst.boardListTabMain.view_list[index].boardListControls.listViewParts.FocusedItem != null) &&
                    (MainFormConst.boardListTabMain.view_list[index].boardListControls.listViewParts.FocusedItem_Name.Length > 0))
                {
                    AllTrue();
                }
                //Xg̃ACeIĂȂ
                else
                {
                    AllFalse();
                }
            }
        }

        public void AllTrue()
        {
            menuItemDownloadParts.Enabled = true;
            menuItemAddFavoriteParts.Enabled = true;
            menuItemOpenBrowserParts.Enabled = true;
            menuItemCopyURLParts.Enabled = true;
            menuItemCopyTitleParts.Enabled = true;
            menuItemAlreadyReadParts.Enabled = true;
            menuItemNotReadParts.Enabled = true;
            //menuItemSelectAllParts.Enabled = true;
            menuItemDeleteLogParts.Enabled = true;
            menuItemSaveHtmlParts.Enabled = true;
            menuItemSaveDatParts.Enabled = true;
        }

        public void AllFalse()
        {
            menuItemDownloadParts.Enabled = false;
            menuItemAddFavoriteParts.Enabled = false;
            menuItemOpenBrowserParts.Enabled = false;
            menuItemCopyURLParts.Enabled = false;
            menuItemCopyTitleParts.Enabled = false;
            menuItemAlreadyReadParts.Enabled = false;
            menuItemNotReadParts.Enabled = false;
            //menuItemSelectAllParts.Enabled = false;
            menuItemDeleteLogParts.Enabled = false;
            menuItemSaveHtmlParts.Enabled = false;
            menuItemSaveDatParts.Enabled = false;
        }
    }
}

==> AgeOn2.7_source.zip: AgeOn2.7_source/nispi/Controls/Menu/MainMenu/BoardListViewMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;
using System.Net;
using System.IO;
using System.Threading;

using nispi.controlclass;
using nispi.Menu;

namespace nispi
{
    class BoardListViewMainMenu
    {
        public ToolStripMenuItemParts menuItemDownloadParts;
        public ToolStripMenuItemParts menuItemAddFavoriteParts;
        public ToolStripMenuItemParts menuItemAlreadyReadParts;
        public ToolStripMenuItemParts menuItemNotReadParts;
        public ToolStripMenuItemParts menuItemCopyURLParts;
        public ToolStripMenuItemParts menuItemCopyTitleParts;
        //public ToolStripMenuItemParts menuItemSelectAllParts;
        public ToolStripMenuItemParts menuItemDeleteLogParts;
        public ToolStripMenuItemParts menuItemSaveHtmlParts;
        public ToolStripMenuItemParts menuItemSaveDatParts;
        public ToolStripMenuItemParts menuItemOpenBrowserParts;
        public ToolStripMenuItemParts menuItemReloadParts;

        public ListViewPartMenuEvent listViewPartMenuEvent;

        public BoardListViewMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemDownloadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAddFavoriteParts = ToolStripMenuItemPartsManager.Pop();
            menuItemAlreadyReadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemNotReadParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyURLParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyTitleParts = ToolStripMenuItemPartsManager.Pop();
            //menuItemSelectAllParts = ToolStripMenuItemPartsManager.Pop();
            menuItemDeleteLogParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSaveHtmlParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSaveDatParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenBrowserParts = ToolStripMenuItemPartsManager.Pop();
            menuItemReloadParts = ToolStripMenuItemPartsManager.Pop();

            //Cj[̐ݒ
            menuItemDownloadParts.Text = "J(&E)";

            menuItemAddFavoriteParts.Text = "Cɓɒǉ(&F)";

            menuItemAlreadyReadParts.Text = "ǂɂ(&Z)";

            menuItemNotReadParts.Text = "ǂɂ(&X)";

            menuItemCopyURLParts.Text = "URLRs[(&C)";

            menuItemCopyTitleParts.Text = "ORs[(&T)";

            //menuItemSelectAllParts.Text = "ׂđI";

            menuItemDeleteLogParts.Text = "O폜(&D)";

            menuItemSaveHtmlParts.Text = "HTML`ŕۑ(&S)";

            menuItemSaveDatParts.Text = "DAT`ŕۑ(&G)";

            menuItemOpenBrowserParts.Text = "uEUŊJ(&B)";



            menuItem.DropDownItemsAdd(menuItemDownloadParts);
            menuItem.DropDownItemsAdd(menuItemAddFavoriteParts);
            menuItem.DropDownItemsAdd(menuItemOpenBrowserParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyURLParts);
            menuItem.DropDownItemsAdd(menuItemCopyTitleParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemAlreadyReadParts);
            menuItem.DropDownItemsAdd(menuItemNotReadParts);
            //menuItem.DropDownItemsAdd(menuItemSelectAllParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemDeleteLogParts);
            menuItem.DropDownItemsAdd(menuItemSaveHtmlParts);
            menuItem.DropDownItemsAdd(menuItemSaveDatParts);

            listViewPartMenuEvent = new ListViewPartMenuEvent(this);
        }

        //Cj[̐ݒ
        public void SetMenu()
        {
            int index = Const.form.boardListTabControlParts.SelectedIndex;

            //Cɓ̃^ȕꍇ
            if (index == 0)
            {
                if ((MainFormConst.boardListTabMain.view_list[0].boardListControls.listViewParts.FocusedItem != null) &&
                    (MainFormConst.boardListTabMain.view_list[0].boardListControls.listViewParts.FocusedItem_Name.Length > 0))
                {
                    AllTrue();
                    menuItemAddFavoriteParts.Enabled = false;
                    
                }
                //Xg̃ACeIĂȂ
                else
                {
                    AllFalse();
                }
            }
            else if (index >= 1)
            {
                //Xg̃ACeIĂ
                if ((MainFormConst.boardListTabMain.view_list[index].boardListControls.listViewParts.FocusedItem != null) &&
                    (MainFormConst.boardListTabMain.view_list[index].boardListControls.listViewParts.FocusedItem_Name.Length > 0))
                {
                    AllTrue();
                }
                //Xg̃ACeIĂȂ
                else
                {
                    AllFalse();
                }
            }
        }

        public void AllTrue()
        {
            menuItemDownloadParts.Enabled = true;
            menuItemAddFavoriteParts.Enabled = true;
            menuItemOpenBrowserParts.Enabled = true;
            menuItemCopyURLParts.Enabled = true;
            menuItemCopyTitleParts.Enabled = true;
            menuItemAlreadyReadParts.Enabled = true;
            menuItemNotReadParts.Enabled = true;
            //menuItemSelectAllParts.Enabled = true;
            menuItemDeleteLogParts.Enabled = true;
            menuItemSaveHtmlParts.Enabled = true;
            menuItemSaveDatParts.Enabled = true;
        }

        public void AllFalse()
        {
            menuItemDownloadParts.Enabled = false;
            menuItemAddFavoriteParts.Enabled = false;
            menuItemOpenBrowserParts.Enabled = false;
            menuItemCopyURLParts.Enabled = false;
            menuItemCopyTitleParts.Enabled = false;
            menuItemAlreadyReadParts.Enabled = false;
            menuItemNotReadParts.Enabled = false;
            //menuItemSelectAllParts.Enabled = false;
            menuItemDeleteLogParts.Enabled = false;
            menuItemSaveHtmlParts.Enabled = false;
            menuItemSaveDatParts.Enabled = false;
        }
    }
}
